package com.css.simulation.resource.home.ctrl;

import api.common.pojo.common.PageVO;
import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.vo.home.*;
import com.css.simulation.resource.algorithm.service.AlgorithmService;
import com.css.simulation.resource.home.service.HomePageService;
import com.css.simulation.resource.model.service.ConfigService;
import com.css.simulation.resource.project.service.SimulationProjectService;
import com.css.simulation.resource.scene.service.SceneNaturalService;
import com.css.simulation.resource.system.service.ClusterService;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;

//首页系统概览
@Slf4j
@RestController
@RequestMapping("/homePage")
public class HomePageCtrl {
    @Autowired
    SceneNaturalService sceneNaturalService;
    @Autowired
    AlgorithmService algorithmService;
    @Autowired
    SimulationProjectService simulationProjectService;
    @Autowired
    ConfigService configService;
    @Autowired
    HomePageService homePageService;
    @Autowired
    ClusterService clusterService;

    //首页概况汇总方法
    @PostMapping("/queryAllNum")
    @ResponseBody
    public ResponseBodyVO<Map<String,Integer>> queryAllNum() {

        Map<String,Integer> map = algorithmService.selectDetailsBySy();//算法文件数量
        map.put("ConfigTotal", configService.getConfigTotal());//车辆配置数量
        map.put("SceneNum", sceneNaturalService.querySceneNumBySy());//场景数量
        map.put("maxConcurrency", clusterService.getLicenseNum());//最大并发数量
        map.put("currentConcurrency", homePageService.getRuningTask());//当前并发数量
        return new ResponseBodyVO<>(ResponseBodyVO.Response.SUCCESS, map);
    }

    /**
     * 近一周运行运行项目数量
     */
    @RequestMapping("selectRunProjectBySy")
    @ResponseBody
    public ResponseBodyVO selectRunProjectBySy() {
        List<LineChartVO> list = homePageService.selectRunProjectChart();
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS,list);
    }

    /**
     * 近一周运行任务数量
     */
    @RequestMapping("selectRunTaskBySy")
    @ResponseBody
    public ResponseBodyVO selectRunTaskBySy() {
        List<LineChartVO> list = homePageService.selectRunTaskChart();
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS,list);
    }

    /**
     * 任务运行状态统计-饼图
     */
    @RequestMapping("selectRunTaskByState")
    @ResponseBody
    public ResponseBodyVO selectRunTaskByState() {
        return simulationProjectService.selectRunTaskByState();
    }

    /**
     * 项目运行状态统计-饼图
     */
    @RequestMapping("selectRunProjectByState")
    @ResponseBody
    public ResponseBodyVO selectRunProjectByState() {
        return simulationProjectService.selectRunProjectByState();
    }

    /**
     * 评测等级分布-饼图
     */
    @RequestMapping("selectEvaluationLevel")
    @ResponseBody
    public ResponseBodyVO selectEvaluationLevel() {
        return simulationProjectService.selectEvaluationLevel();
    }


    /**
     * 硬件监控
     */
    @RequestMapping("selectHardware")
    @ResponseBody
    public ResponseBodyVO<HardwareVO> selectHardware() {
        return homePageService.selectHardware();
    }

    /**
     * 服务监控
     */
    @RequestMapping("selectService")
    @ResponseBody
    public ResponseBodyVO<ServiceVO> selectService() {
        return homePageService.selectService();
    }

    /**
     * 日访问人数
     */
    @RequestMapping("selectAccess")
    @ResponseBody
    public ResponseBodyVO<List<LineChartVO>> selectAccess() {
        List<LineChartVO> list = homePageService.selectAccess();
        return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS,list);
    }


    /**
     * 服务器监控
     */
    @RequestMapping("selectServer")
    @ResponseBody
    public ResponseBodyVO<PageInfo<SystemServerVO>> selectServer(PageVO pageVO) {
        return homePageService.selectServer(pageVO);
    }
}